pub struct MockOrganizationConnectionsApi {
OrganizationConnectionsApi_expectations: MockOrganizationConnectionsApi_OrganizationConnectionsApi,
}Fields
OrganizationConnectionsApi_expectations: MockOrganizationConnectionsApi_OrganizationConnectionsApiImplementations
Sourceimpl MockOrganizationConnectionsApi
impl MockOrganizationConnectionsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationConnectionsApi
impl MockOrganizationConnectionsApi
Sourcepub fn expect_connections_enabled(&mut self) -> &mut Expectation
pub fn expect_connections_enabled(&mut self) -> &mut Expectation
Create an Expectation for mocking the connections_enabled method
Sourcepub fn expect_create_connection(&mut self) -> &mut Expectation
pub fn expect_create_connection(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_connection method
Sourcepub fn expect_delete_connection(&mut self) -> &mut Expectation
pub fn expect_delete_connection(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_connection method
Sourcepub fn expect_get_connection(&mut self) -> &mut Expectation
pub fn expect_get_connection(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_connection method
Sourcepub fn expect_update_connection(&mut self) -> &mut Expectation
pub fn expect_update_connection(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_connection method